@@ -136,7 +136,7 @@ fit_model <- function(main_dir,
     # Priors for wrapped cauchy
     for(g in 1:Gsmall){
       # g = cluster
-      gamma[g] ~ dgamma(a, b)
+      gamma[g] ~ dgamma(a, b) T(0.1,)
       eta[g] ~ dunif(0,2*pi_constant)
       for(w in 1:W){
         # W = num unique writers
@@ -292,10 +292,16 @@ about_variable <- function(variable, model) {
 #'
 #' @export
 #' @md
-get_credible_intervals <- function(model, interval_min=0.025, interval_max=0.975){
+get_credible_intervals <- function(model, interval_min = 0.05, interval_max = 0.95){
   pis <- get_pi_dataframes(model)
-  ci <- lapply(1:model$rjags_data$W, function(i) get_credible_intervals_for_writer(writer=i, 
-                                                                                   writer_pis=pis[[i]]))
+  writerIDs <- levels(model$rjags_data$docwriter)
+  ci <- lapply(1:model$rjags_data$W, function(i) {get_credible_intervals_for_writer(
+    model = model,
+    writer = i,
+    writerID = writerIDs[i],
+    writer_pis = pis[[i]],
+    interval_min = interval_min,
+    interval_max = interval_max)})
   return(ci)
 }
 
@@ -402,19 +408,27 @@ get_pi_dataframes <- function(model) {
 #' get_credible_intervals_for_writer
 #'
 #' Calculate the median and credible intervals for the pi parameters for a writer
-#'
-#' @param writer The writer ID
+#' 
+#' @param model A model created with `fit_model`
+#' @param writer The model sequentially numbers the writers. `writer` is the sequential writer number.
+#' @param writerID The writer ID
 #' @param writer_pis The formatted data frame of pi parameters for the writer created by `get_pi_dataframes`
 #' @param interval_min The lower bound of the credible interval
 #' @param interval_max The upper bound of the credible interval
 #' @return A data frame
 #'
 #' @noRd
-get_credible_intervals_for_writer <- function(writer, writer_pis, interval_min=0.025, interval_max=0.975){
+get_credible_intervals_for_writer <- function(model, 
+                                              writer, 
+                                              writerID, 
+                                              writer_pis, 
+                                              interval_min=0.025, 
+                                              interval_max=0.975){
+  
   df <- sapply(writer_pis[,-which(names(writer_pis) %in% c("iter", "writer"))], 
                function(x) stats::quantile(x,  probs = c(interval_min, 0.5, interval_max)), USE.NAMES = FALSE)
   df <- data.frame(quantile = row.names(df), df)
-  df$writer <- writer
+  df$writer <- writerID
   rownames(df) <- NULL
   return(df)
 }
